@@ -86,8 +86,9 @@ def test_encoding(host):
     elif host.backend.get_connection_type() == "ansible" and host.backend.force_ansible:
         # XXX: this encoding issue comes directly from ansible
         # not sure how to handle this...
-        assert cmd.stderr == (
-            "ls: impossible d'accéder à '/Ã©': " "Aucun fichier ou dossier de ce type"
+        assert (
+            cmd.stderr
+            == "ls: impossible d'acc\udce9der \udce0 '/é': Aucun fichier ou dossier de ce type"
         )
     else:
         assert cmd.stderr_bytes == (
@@ -95,7 +96,7 @@ def test_encoding(host):
             b"Aucun fichier ou dossier de ce type\n"
         )
         assert cmd.stderr == (
-            "ls: impossible d'accéder à '/é': " "Aucun fichier ou dossier de ce type\n"
+            "ls: impossible d'accéder à '/é': Aucun fichier ou dossier de ce type\n"
         )
 
 
@@ -124,18 +125,16 @@ def test_sudo(host):
 def test_ansible_get_hosts():
     with tempfile.NamedTemporaryFile() as f:
         f.write(
-            (
-                b"ungrp\n"
-                b"[g1]\n"
-                b"debian\n"
-                b"[g2]\n"
-                b"rockylinux\n"
-                b"[g3:children]\n"
-                b"g1\n"
-                b"g2\n"
-                b"[g4:children]\n"
-                b"g3"
-            )
+            b"ungrp\n"
+            b"[g1]\n"
+            b"debian\n"
+            b"[g2]\n"
+            b"rockylinux\n"
+            b"[g3:children]\n"
+            b"g1\n"
+            b"g2\n"
+            b"[g4:children]\n"
+            b"g3"
         )
         f.flush()
 
@@ -157,16 +156,14 @@ def test_ansible_get_hosts():
 def test_ansible_get_variables():
     with tempfile.NamedTemporaryFile() as f:
         f.write(
-            (
-                b"debian a=b c=d\n"
-                b"rockylinux e=f\n"
-                b"[all:vars]\n"
-                b"a=a\n"
-                b"[g]\n"
-                b"debian\n"
-                b"[g:vars]\n"
-                b"x=z\n"
-            )
+            b"debian a=b c=d\n"
+            b"rockylinux e=f\n"
+            b"[all:vars]\n"
+            b"a=a\n"
+            b"[g]\n"
+            b"debian\n"
+            b"[g:vars]\n"
+            b"x=z\n"
         )
         f.flush()
 
@@ -201,7 +198,7 @@ def test_ansible_get_variables():
         (
             {},
             b"host ansible_connection=local ansible_become=yes ansible_become_user=u",
-            {  # noqa
+            {
                 "NAME": "local",
                 "sudo": True,
                 "sudo_user": "u",
@@ -226,7 +223,7 @@ def test_ansible_get_variables():
         (
             {},
             b"host ansible_host=127.0.1.1 ansible_user=u ansible_ssh_private_key_file=key ansible_port=2222 ansible_become=yes ansible_become_user=u",
-            {  # noqa
+            {
                 "NAME": "ssh",
                 "sudo": True,
                 "sudo_user": "u",
@@ -238,7 +235,7 @@ def test_ansible_get_variables():
         (
             {},
             b"host ansible_host=127.0.1.1 ansible_user=u ansible_private_key_file=key ansible_port=2222 ansible_become=yes ansible_become_user=u",
-            {  # noqa
+            {
                 "NAME": "ssh",
                 "sudo": True,
                 "sudo_user": "u",
@@ -268,7 +265,7 @@ def test_ansible_get_variables():
         (
             {},
             b'host ansible_ssh_common_args="-o StrictHostKeyChecking=no" ansible_ssh_extra_args="-o LogLevel=FATAL"',
-            {  # noqa
+            {
                 "NAME": "ssh",
                 "host.name": "host",
                 "ssh_extra_args": "-o StrictHostKeyChecking=no -o LogLevel=FATAL",
@@ -295,7 +292,7 @@ def test_ansible_get_variables():
         (
             {},
             b"host ansible_connection=docker ansible_become=yes ansible_become_user=u ansible_user=z ansible_host=container",
-            {  # noqa
+            {
                 "NAME": "docker",
                 "name": "container",
                 "user": "z",
@@ -346,7 +343,7 @@ def test_ansible_get_host(kwargs, inventory, expected):
         # identity_file has highest priority
         (
             b"host ansible_user=user ansible_ssh_pass=password ansible_ssh_private_key_file=some_file",
-            (  # noqa
+            (
                 "ssh -o User=user -i some_file "
                 "-o ConnectTimeout=10 -o ControlMaster=auto "
                 "-o ControlPersist=60s host true"
@@ -372,7 +369,7 @@ def test_ansible_get_host(kwargs, inventory, expected):
         # escape %
         (
             b'host ansible_ssh_extra_args="-o ControlPath ~/.ssh/ansible/cp/%r@%h-%p"',
-            (  # noqa
+            (
                 "ssh -o ControlPath ~/.ssh/ansible/cp/%r@%h-%p -o ConnectTimeout=10 "
                 "-o ControlMaster=auto -o ControlPersist=60s host true"
             ),
@@ -418,7 +415,7 @@ def test_ansible_config():
     # test testinfra use ANSIBLE_CONFIG
     tmp = tempfile.NamedTemporaryFile
     with tmp(suffix=".cfg") as cfg, tmp() as inventory:
-        cfg.write((b"[defaults]\n" b"inventory=" + inventory.name.encode() + b"\n"))
+        cfg.write(b"[defaults]\ninventory=" + inventory.name.encode() + b"\n")
         cfg.flush()
         inventory.write(b"h\n")
         inventory.flush()
@@ -640,3 +637,12 @@ def test_get_hosts():
         ("a", 10),
         ("a", 1),
     ]
+
+
+@pytest.mark.testinfra_hosts(*HOSTS)
+def test_command_deadlock(host):
+    # Test for deadlock when exceeding Paramiko transport buffer (2MB)
+    # https://docs.paramiko.org/en/latest/api/channel.html#paramiko.channel.Channel.recv_exit_status
+    size = 3 * 1024 * 1024
+    output = host.check_output(f"python3 -c 'print(\"a\" * {size})'")
+    assert len(output) == size
