@@ -10,20 +10,22 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import crypt
 import datetime
 import os
 import re
+import tempfile
+import textwrap
 import time
 from ipaddress import IPv4Address, IPv6Address, ip_address
 
 import pytest
 
 from testinfra.modules.socket import parse_socketspec
+from testinfra.utils.ansible_runner import AnsibleRunner
 
 all_images = pytest.mark.testinfra_hosts(
     *[
-        "docker://{}".format(image)
+        f"docker://{image}"
         for image in (
             "rockylinux9",
             "debian_bookworm",
@@ -48,7 +50,7 @@ def test_package(host, docker_image):
     }[docker_image]
     if release is None:
         with pytest.raises(NotImplementedError):
-            ssh.release
+            ssh.release  # noqa: B018
     else:
         assert release in ssh.release
 
@@ -64,7 +66,7 @@ def test_held_package(host):
 def test_rpmdb_corrupted(host):
     host.check_output("dd if=/dev/zero of=/var/lib/rpm/rpmdb.sqlite bs=1024 count=1")
     with pytest.raises(RuntimeError) as excinfo:
-        host.package("zsh").is_installed
+        host.package("zsh").is_installed  # noqa: B018
     assert (
         "Could not check if RPM package 'zsh' is installed. error: sqlite failure:"
     ) in str(excinfo.value)
@@ -80,7 +82,7 @@ def test_non_default_package_tool(host):
 @pytest.mark.destructive
 def test_uninstalled_package_version(host):
     with pytest.raises(AssertionError) as excinfo:
-        host.package("zsh").version
+        host.package("zsh").version  # noqa: B018
     assert (
         "The package zsh is not installed, dpkg-query output: unknown ok not-installed"
         in str(excinfo.value)
@@ -89,7 +91,7 @@ def test_uninstalled_package_version(host):
     host.check_output("apt-get -y remove sudo")
     assert not host.package("sudo").is_installed
     with pytest.raises(AssertionError) as excinfo:
-        host.package("sudo").version
+        host.package("sudo").version  # noqa: B018
     assert (
         "The package sudo is not installed, dpkg-query output: "
         "deinstall ok config-files 1.9."
@@ -112,11 +114,7 @@ def test_systeminfo(host, docker_image):
 
 @all_images
 def test_ssh_service(host, docker_image):
-    if docker_image == "rockylinux9":
-        name = "sshd"
-    else:
-        name = "ssh"
-
+    name = "sshd" if docker_image == "rockylinux9" else "ssh"
     ssh = host.service(name)
     # wait at max 10 seconds for ssh is running
     for _ in range(10):
@@ -194,7 +192,7 @@ def test_socket(host):
 
     assert not host.socket("tcp://4242").is_listening
 
-    if not host.backend.get_connection_type() == "docker":
+    if host.backend.get_connection_type() != "docker":
         # FIXME
         for spec in (
             "tcp://22",
@@ -232,6 +230,13 @@ def test_user(host):
     assert user.password == "!"
 
 
+def test_user_get_all_users(host):
+    user_list = host.user("root").get_all_users
+    assert "root" in user_list
+    assert "man" in user_list
+    assert "nobody" in user_list
+
+
 def test_user_password_days(host):
     assert host.user("root").password_max_days == 99999
     assert host.user("root").password_min_days == 0
@@ -247,7 +252,7 @@ def test_user_user(host):
 
 def test_user_expiration_date(host):
     assert host.user("root").expiration_date is None
-    assert host.user("user").expiration_date == (datetime.datetime(2024, 10, 4, 0, 0))
+    assert host.user("user").expiration_date == datetime.datetime(2030, 1, 1)
 
 
 def test_nonexistent_user(host):
@@ -257,12 +262,19 @@ def test_nonexistent_user(host):
 def test_current_user(host):
     assert host.user().name == "root"
     pw = host.user().password
-    assert crypt.crypt("foo", pw) == pw
+    assert pw.startswith("$")
+    assert len(pw) == 73
 
 
 def test_group(host):
     assert host.group("root").exists
     assert host.group("root").gid == 0
+    group_list = host.group("root").get_all_groups
+    assert "root" in group_list
+    assert "bin" in group_list
+    group_list = host.group("root").get_local_groups
+    assert "root" in group_list
+    assert "bin" in group_list
 
 
 def test_empty_command_output(host):
@@ -308,7 +320,7 @@ def test_file(host):
     assert link.linked_to == "/d/f"
     assert link.linked_to == f
     assert f == host.file("/d/f")
-    assert not d == f
+    assert d != f
 
     host.check_output("ln /d/f /d/h")
     hardlink = host.file("/d/h")
@@ -318,7 +330,7 @@ def test_file(host):
     assert isinstance(f.inode, int)
     assert hardlink.inode == f.inode
     assert f == host.file("/d/f")
-    assert not d == f
+    assert d != f
 
     host.check_output("rm -f /d/p && mkfifo /d/p")
     assert host.file("/d/p").is_pipe
@@ -329,7 +341,7 @@ def test_file(host):
 
 
 def test_ansible_unavailable(host):
-    expected = "Ansible module is only available with " "ansible connection backend"
+    expected = "Ansible module is only available with ansible connection backend"
     with pytest.raises(RuntimeError) as excinfo:
         host.ansible("setup")
     assert expected in str(excinfo.value)
@@ -354,6 +366,24 @@ def test_ansible_module(host):
     assert passwd["state"] in ("file", "hard")
     assert passwd["uid"] == 0
 
+    with pytest.raises(host.ansible.AnsibleException) as excinfo:
+        host.ansible("command", "zzz")
+    assert excinfo.value.result["msg"] == "Skipped. You might want to try check=False"
+
+    try:
+        host.ansible("command", "zzz", check=False)
+    except host.ansible.AnsibleException as exc:
+        assert exc.result["rc"] == 2
+        # notez que the debian bookworm container is set to LANG=fr_FR
+        assert exc.result["msg"] == ("[Errno 2] Aucun fichier ou dossier de ce type")
+
+    result = host.ansible("command", "echo foo", check=False)
+    assert result["stdout"] == "foo"
+
+
+@pytest.mark.testinfra_hosts("ansible://debian_bookworm")
+def test_ansible_get_variables_flat_wo_child_groups(host):
+    """Test AnsibleRunner.get_variables() with parent groups only"""
     variables = host.ansible.get_variables()
     assert variables["myvar"] == "foo"
     assert variables["myhostvar"] == "bar"
@@ -365,19 +395,31 @@ def test_ansible_module(host):
         "testgroup": ["debian_bookworm"],
     }
 
-    with pytest.raises(host.ansible.AnsibleException) as excinfo:
-        host.ansible("command", "zzz")
-    assert excinfo.value.result["msg"] == "Skipped. You might want to try check=False"
 
-    try:
-        host.ansible("command", "zzz", check=False)
-    except host.ansible.AnsibleException as exc:
-        assert exc.result["rc"] == 2
-        # notez que the debian bookworm container is set to LANG=fr_FR
-        assert exc.result["msg"] == ("[Errno 2] Aucun fichier ou dossier " "de ce type")
+def test_ansible_get_variables_w_child_groups():
+    """Test AnsibleRunner.get_variables() with parent and child groups"""
+    inventory = """
+        host_a
+        [toplevel1]
+        host_b
+        [toplevel2]
+        host_c
+        [toplevel3:children]
+        toplevel1
+        """
+    with tempfile.NamedTemporaryFile(mode="wt", encoding="ascii") as file_inventory:
+        file_inventory.write(textwrap.dedent(inventory.strip()))
+        file_inventory.flush()
 
-    result = host.ansible("command", "echo foo", check=False)
-    assert result["stdout"] == "foo"
+        get_variables = AnsibleRunner(file_inventory.name).get_variables
+
+        assert get_variables("host_a")["group_names"] == ["all", "ungrouped"]
+        assert get_variables("host_b")["group_names"] == [
+            "all",
+            "toplevel1",
+            "toplevel3",
+        ]
+        assert get_variables("host_c")["group_names"] == ["all", "toplevel2"]
 
 
 @pytest.mark.testinfra_hosts(
@@ -439,9 +481,8 @@ def test_supervisor(host, supervisorctl_path, supervisorctl_conf):
         )
         if service.status == "RUNNING":
             break
-        else:
-            assert service.status == "STARTING"
-            time.sleep(0.5)
+        assert service.status == "STARTING"
+        time.sleep(0.5)
     else:
         raise RuntimeError("No running tail in supervisor")
 
@@ -471,7 +512,7 @@ def test_supervisor(host, supervisorctl_path, supervisorctl_conf):
     host.run("service supervisor stop")
     assert not host.service("supervisor").is_running
     with pytest.raises(RuntimeError) as excinfo:
-        host.supervisor(
+        host.supervisor(  # noqa: B018
             "tail",
             supervisorctl_path=supervisorctl_path,
             supervisorctl_conf=supervisorctl_conf,
@@ -482,12 +523,14 @@ def test_supervisor(host, supervisorctl_path, supervisorctl_conf):
 def test_mountpoint(host):
     root_mount = host.mount_point("/")
     assert root_mount.exists
+    assert repr(root_mount)
     assert isinstance(root_mount.options, list)
     assert "rw" in root_mount.options
     assert root_mount.filesystem
 
     fake_mount = host.mount_point("/fake/mount")
     assert not fake_mount.exists
+    assert repr(fake_mount)
 
     mountpoints = host.mount_point.get_mountpoints()
     assert mountpoints
@@ -504,9 +547,9 @@ def test_sudo_from_root(host):
 
 def test_sudo_fail_from_root(host):
     assert host.user().name == "root"
-    with pytest.raises(AssertionError) as exc:
-        with host.sudo("unprivileged"):
-            assert host.user().name == "unprivileged"
+    with host.sudo("unprivileged"):
+        assert host.user().name == "unprivileged"
+        with pytest.raises(AssertionError) as exc:
             host.check_output("ls /root/invalid")
     assert str(exc.value).startswith("Unexpected exit code")
     with host.sudo():
@@ -579,12 +622,9 @@ def test_ip6tables(host):
     try:
         v6_rules = host.iptables.rules(version=6)
     except AssertionError as exc_info:
-        if (
-            "Perhaps ip6tables or your kernel needs to "
-            "be upgraded" in exc_info.args[0]
-        ):
+        if "Perhaps ip6tables or your kernel needs to be upgraded" in exc_info.args[0]:
             pytest.skip(
-                f"IPV6 does not seem to be enabled on the docker host" f"\n{exc_info}"
+                f"IPV6 does not seem to be enabled on the docker host\n{exc_info}"
             )
         else:
             raise
