@@ -19,11 +19,9 @@ try:
     import winrm
 except ImportError:
     raise RuntimeError(
-        (
-            "You must install the pywinrm package (pip install pywinrm) "
-            "to use the winrm backend"
-        )
-    )
+        "You must install the pywinrm package (pip install pywinrm) "
+        "to use the winrm backend"
+    ) from None
 
 import winrm.protocol
 
@@ -64,7 +62,7 @@ class WinRMBackend(base.BaseBackend):
             "endpoint": "{}://{}{}/wsman".format(
                 "http" if no_ssl else "https",
                 self.host.name,
-                ":{}".format(self.host.port) if self.host.port else "",
+                f":{self.host.port}" if self.host.port else "",
             ),
             "transport": "ntlm",
             "username": self.host.user,
@@ -81,10 +79,10 @@ class WinRMBackend(base.BaseBackend):
     def run(self, command: str, *args: str, **kwargs: Any) -> base.CommandResult:
         return self.run_winrm(self.get_command(command, *args))
 
-    def run_winrm(self, command: str, *args: str) -> base.CommandResult:
+    def run_winrm(self, command: str) -> base.CommandResult:
         p = winrm.protocol.Protocol(**self.conn_args)
         shell_id = p.open_shell()
-        command_id = p.run_command(shell_id, command, *args)
+        command_id = p.run_command(shell_id, command)
         stdout, stderr, rc = p.get_command_output(shell_id, command_id)
         p.cleanup_command(shell_id, command_id)
         p.close_shell(shell_id)
@@ -93,5 +91,5 @@ class WinRMBackend(base.BaseBackend):
     @staticmethod
     def quote(command: str, *args: str) -> str:
         if args:
-            return command % tuple(_quote(a) for a in args)  # noqa: S001
+            return command % tuple(_quote(a) for a in args)
         return command
