@@ -10,11 +10,14 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+from __future__ import annotations
+
 import logging
 import shutil
 import sys
 import tempfile
 import time
+from typing import AnyStr, cast
 
 import pytest
 
@@ -24,19 +27,19 @@ import testinfra.modules
 
 
 @pytest.fixture(scope="module")
-def _testinfra_host(request):
-    return request.param
+def _testinfra_host(request: pytest.FixtureRequest) -> testinfra.host.Host:
+    return cast(testinfra.host.Host, request.param)
 
 
 @pytest.fixture(scope="module")
-def host(_testinfra_host):
+def host(_testinfra_host: testinfra.host.Host) -> testinfra.host.Host:
     return _testinfra_host
 
 
 host.__doc__ = testinfra.host.Host.__doc__
 
 
-def pytest_addoption(parser):
+def pytest_addoption(parser: pytest.Parser) -> None:
     group = parser.getgroup("testinfra")
     group.addoption(
         "--connection",
@@ -106,7 +109,7 @@ def pytest_addoption(parser):
     )
 
 
-def pytest_generate_tests(metafunc):
+def pytest_generate_tests(metafunc: pytest.Metafunc) -> None:
     if "_testinfra_host" in metafunc.fixturenames:
         if metafunc.config.option.hosts is not None:
             hosts = metafunc.config.option.hosts.split(",")
@@ -140,7 +143,7 @@ class NagiosReporter:
         self.total_time = None
         self.out = out
 
-    def pytest_runtest_logreport(self, report):
+    def pytest_runtest_logreport(self, report: pytest.TestReport) -> None:
         if report.passed:
             if report.when == "call":  # ignore setup/teardown
                 self.passed += 1
@@ -149,7 +152,7 @@ class NagiosReporter:
         elif report.skipped:
             self.skipped += 1
 
-    def report(self):
+    def report(self) -> int:
         if self.failed:
             status = b"CRITICAL"
             ret = 2
@@ -159,7 +162,7 @@ class NagiosReporter:
 
         out = sys.stdout.buffer
         out.write(
-            (b"TESTINFRA %s - %d passed, %d failed, %d skipped in %.2f " b"seconds\n")
+            (b"TESTINFRA %s - %d passed, %d failed, %d skipped in %.2f seconds\n")
             % (
                 status,
                 self.passed,
@@ -173,7 +176,7 @@ class NagiosReporter:
         return ret
 
 
-class SpooledTemporaryFile(tempfile.SpooledTemporaryFile):
+class SpooledTemporaryFile(tempfile.SpooledTemporaryFile[AnyStr]):
     def __init__(self, *args, **kwargs):
         if "b" in kwargs.get("mode", "b"):
             self._out_encoding = kwargs.pop("encoding")
@@ -189,7 +192,7 @@ class SpooledTemporaryFile(tempfile.SpooledTemporaryFile):
         return super().write(s)
 
 
-@pytest.mark.trylast
+@pytest.hookimpl(trylast=True)
 def pytest_configure(config):
     if config.getoption("--verbose", 0) > 1:
         root = logging.getLogger()
@@ -207,7 +210,7 @@ def pytest_configure(config):
             config.pluginmanager.register(NagiosReporter(out), "nagiosreporter")
 
 
-@pytest.mark.trylast
+@pytest.hookimpl(trylast=True)
 def pytest_sessionfinish(session, exitstatus):
     reporter = session.config.pluginmanager.getplugin("nagiosreporter")
     if reporter:
